summaryrefslogtreecommitdiff
path: root/src/mongo/db/client.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/client.h')
-rw-r--r--src/mongo/db/client.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/client.h b/src/mongo/db/client.h
index 50d4f5de541..32d8de0fc04 100644
--- a/src/mongo/db/client.h
+++ b/src/mongo/db/client.h
@@ -155,12 +155,12 @@ public:
ServiceContext::UniqueOperationContext makeOperationContext();
/**
* Sets the active operation context on this client to "txn", which must be non-NULL.
*
* It is an error to call this method if there is already an operation context on Client.
* It is an error to call this on an unlocked client.
*/
- void setOperationContext(OperationContext* txn);
+ void setOperationContext(OperationContext* opCtx);
/**
* Clears the active operation context on this client.
@@ -177,7 +177,7 @@ public:
* by this method while the client is not locked.
*/
OperationContext* getOperationContext() {
- return _txn;
+ return _opCtx;
}
// TODO(spencer): SERVER-10228 SERVER-14779 Remove this/move it fully into OperationContext.
@@ -224,7 +224,7 @@ private:
bool _inDirectClient = false;
// If != NULL, then contains the currently active OperationContext
- OperationContext* _txn = nullptr;
+ OperationContext* _opCtx = nullptr;
PseudoRandom _prng;
};
@@ -155,12 +155,12 @@ public:
ServiceContext::UniqueOperationContext makeOperationContext();
/**
- * Sets the active operation context on this client to "txn", which must be non-NULL.
+ * Sets the active operation context on this client to "opCtx", which must be non-NULL.
*
* It is an error to call this method if there is already an operation context on Client.